@@ -23,8 +23,10 @@ module Data.Vector.Unboxed.Deriving
       derivingUnbox
     ) where
 
-import Control.Arrow
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative
+#endif
+import Control.Arrow
 import Control.Monad
 import Data.Char (isAlphaNum)
 import qualified Data.Vector.Generic as G
@@ -120,6 +122,9 @@ derivingUnbox name argsQ toRepQ fromRepQ = do
             , wrap 'M.basicUnsafeSlice      [i, n, mv]  (AppE mvCon)
             , wrap 'M.basicOverlaps         [mv, mv']   id
             , wrap 'M.basicUnsafeNew        [n]         (liftE mvCon)
+#if MIN_VERSION_vector(0,11,0)
+            , wrap 'M.basicInitialize       [mv]        id
+#endif
             , wrap 'M.basicUnsafeReplicate  [n, a]      (liftE mvCon)
             , wrap 'M.basicUnsafeRead       [mv, i]     (liftE fromRep)
             , wrap 'M.basicUnsafeWrite      [mv, i, a]  id
